searchNodes=[{"doc":"Belp is a simple Boolean Expression Lexer and Parser.","ref":"Belp.html","title":"Belp","type":"module"},{"doc":"Evaluates the given expression. Examples iex&gt; Belp.eval(&quot;foo and bar&quot;, foo: true, bar: false) {:ok, false} iex&gt; Belp.eval(&quot;foo or bar&quot;, %{&quot;foo&quot; =&gt; true, &quot;bar&quot; =&gt; false}) {:ok, true} iex&gt; Belp.eval(&quot;bar&quot;, %{foo: true}) {:error, %Belp.UndefinedVariableError{var: &quot;bar&quot;}} iex&gt; Belp.eval(&quot;invalid expression&quot;) {:error, %Belp.SyntaxError{line: 1, token: &quot;expression&quot;}} iex&gt; Belp.eval(&quot;foo || bar&quot;) {:error, %Belp.InvalidCharError{char: &quot;|&quot;, line: 1}}","ref":"Belp.html#eval/2","title":"Belp.eval/2","type":"function"},{"doc":"Evaluates the given expression. Raises when the expression is invalid or variables are undefined. Examples iex&gt; Belp.eval!(&quot;foo and bar&quot;, foo: true, bar: false) false iex&gt; Belp.eval!(&quot;foo or bar&quot;, %{&quot;foo&quot; =&gt; true, &quot;bar&quot; =&gt; false}) true iex&gt; Belp.eval!(&quot;bar&quot;, %{foo: true}) ** (Belp.UndefinedVariableError) Undefined variable: bar iex&gt; Belp.eval!(&quot;invalid expression&quot;) ** (Belp.SyntaxError) Syntax error near token &quot;expression&quot; on line 1 iex&gt; Belp.eval!(&quot;foo || bar&quot;) ** (Belp.InvalidCharError) Invalid character &quot;|&quot; on line 1","ref":"Belp.html#eval!/2","title":"Belp.eval!/2","type":"function"},{"doc":"Checks whether the given expression is valid. Examples iex&gt; Belp.valid_expression?(&quot;foo and bar&quot;) true iex&gt; Belp.valid_expression?(&quot;invalid expression&quot;) false iex&gt; Belp.valid_expression?(&quot;foo || bar&quot;) false","ref":"Belp.html#valid_expression?/1","title":"Belp.valid_expression?/1","type":"function"},{"doc":"Validates the given expression, returning an error tuple in case the expression is invalid. Examples iex&gt; Belp.validate(&quot;foo and bar&quot;) :ok iex&gt; Belp.validate(&quot;invalid expression&quot;) {:error, %Belp.SyntaxError{line: 1, token: &quot;expression&quot;}} iex&gt; Belp.validate(&quot;foo || bar&quot;) {:error, %Belp.InvalidCharError{char: &quot;|&quot;, line: 1}}","ref":"Belp.html#validate/1","title":"Belp.validate/1","type":"function"},{"doc":"Gets a list of variable names that are present in the given expression. Examples iex&gt; Belp.variables(&quot;(foo and bar) or !foo&quot;) {:ok, [&quot;foo&quot;, &quot;bar&quot;]} iex&gt; Belp.variables(&quot;invalid expression&quot;) {:error, %Belp.SyntaxError{line: 1, token: &quot;expression&quot;}} iex&gt; Belp.variables(&quot;foo || bar&quot;) {:error, %Belp.InvalidCharError{char: &quot;|&quot;, line: 1}}","ref":"Belp.html#variables/1","title":"Belp.variables/1","type":"function"},{"doc":"Gets a list of variable names that are present in the given expression. Raises when the expression is invalid or variables are undefined. Examples iex&gt; Belp.variables!(&quot;(foo and bar) or !foo&quot;) [&quot;foo&quot;, &quot;bar&quot;] iex&gt; Belp.variables!(&quot;invalid expression&quot;) ** (Belp.SyntaxError) Syntax error near token &quot;expression&quot; on line 1 iex&gt; Belp.variables!(&quot;foo || bar&quot;) ** (Belp.InvalidCharError) Invalid character &quot;|&quot; on line 1","ref":"Belp.html#variables!/1","title":"Belp.variables!/1","type":"function"},{"doc":"A type that describes which primitives can be used as expression.","ref":"Belp.html#t:expr/0","title":"Belp.expr/0","type":"type"},{"doc":"An error that is returned or raised when a expression contains an invalid char.","ref":"Belp.InvalidCharError.html","title":"Belp.InvalidCharError","type":"exception"},{"doc":"Callback implementation for Exception.message/1.","ref":"Belp.InvalidCharError.html#message/1","title":"Belp.InvalidCharError.message/1","type":"function"},{"doc":"","ref":"Belp.InvalidCharError.html#t:t/0","title":"Belp.InvalidCharError.t/0","type":"type"},{"doc":"An error that is returned or raised when the expression contains a syntax error.","ref":"Belp.SyntaxError.html","title":"Belp.SyntaxError","type":"exception"},{"doc":"Callback implementation for Exception.message/1.","ref":"Belp.SyntaxError.html#message/1","title":"Belp.SyntaxError.message/1","type":"function"},{"doc":"","ref":"Belp.SyntaxError.html#t:t/0","title":"Belp.SyntaxError.t/0","type":"type"},{"doc":"An error that is returned or raised when a variable used in a expression is undefined.","ref":"Belp.UndefinedVariableError.html","title":"Belp.UndefinedVariableError","type":"exception"},{"doc":"Callback implementation for Exception.message/1.","ref":"Belp.UndefinedVariableError.html#message/1","title":"Belp.UndefinedVariableError.message/1","type":"function"},{"doc":"","ref":"Belp.UndefinedVariableError.html#t:t/0","title":"Belp.UndefinedVariableError.t/0","type":"type"},{"doc":"Belp A simple Boolean Expression Lexer and Parser written in Elixir.","ref":"readme.html","title":"Belp","type":"extras"},{"doc":"The package can be installed by adding belp to your list of dependencies in mix.exs: def deps do [ {:belp, &quot;~&gt; 0.2&quot;} ] end","ref":"readme.html#installation","title":"Belp - Installation","type":"extras"},{"doc":"iex&gt; Belp.eval!( ...&gt; &quot;(foo or bar) and not baz&quot;, ...&gt; %{&quot;foo&quot; =&gt; false, &quot;bar&quot; =&gt; true, &quot;baz&quot; =&gt; false} ...&gt; ) true iex&gt; Belp.eval!(&quot;invalid expression&quot;) ** (Belp.SyntaxError) Syntax error near token &quot;expression&quot; on line 1 See HexDocs for the full API.","ref":"readme.html#usage","title":"Belp - Usage","type":"extras"}]